@@ -235,9 +235,14 @@ sub build_data_hash {
 		if (defined($Config{'replaces'}{$pkg})) {
 			$TeXLive{'binary'}{$pkg}{'replaces'} = [ @{$Config{'replaces'}{$pkg}} ];
 		}
-		if (defined($Config{'breaks'}{$pkg})) {
-			$TeXLive{'binary'}{$pkg}{'breaks'} = [ @{$Config{'breaks'}{$pkg}} ];
+		my @breaks;
+		if ($pkg ne "texlive-base") {
+			push @breaks, "texlive-base (<< $TeXLive{'all'}{'tl_common_version'})";
 		}
+		if (defined($Config{'breaks'}{$pkg})) {
+			push @breaks, @{$Config{'breaks'}{$pkg}};
+		}
+		$TeXLive{'binary'}{$pkg}{'breaks'} = [ @breaks ];
 		if (defined($Config{'bin-section'}{$pkg})) {
 			$TeXLive{'binary'}{$pkg}{'section'} = $Config{'bin-section'}{$pkg};
 		}
@@ -597,6 +602,20 @@ sub read_one_config_file {
 			$Config{'breaks'}{$a} = [ @{$Config{'breaks'}{$a}}, split(/[ \t]*,[ \t]*/,$b) ];
 			next;
 		}
+		if ($type eq "filemove") {
+			my ($b,$v) = @rest;
+			$opt_debug && print STDERR "b=$b.\n";
+			# file movement from package A to package B
+			# filemove;A;B;VERSION
+			# see https://wiki.debian.org/PackageTransition
+			# in A: breaks B (<< V)
+			# in B: breaks A (<< V)
+			#       replaces A (<< V)
+			$Config{'breaks'}{$a} = [ @{$Config{'breaks'}{$a}}, "$b (<< $v)" ];
+			$Config{'replaces'}{$a} = [ @{$Config{'replaces'}{$a}}, "$b (<< $v)" ];
+			$Config{'breaks'}{$b} = [ @{$Config{'breaks'}{$b}}, "$a (<< $v)" ];
+			next;
+		}
 		if ($type eq "execute") {
 			my ($b) = @rest;
 			$opt_debug && print STDERR  "b=$b.\n";
